@@ -6,19 +6,16 @@ from typing import IO, List, NamedTuple
 class Pose(NamedTuple):
     name: str
     difficulty: int
-    mirror: bool
-
-
-def open_data(name: str) -> IO[bytes]:
-    return pkg_resources.resource_stream(__name__, name)
+    asymmetric: bool
 
 
 def read_poses() -> List[Pose]:
-    return [Pose(**row) for row in json.load(open_data("data/poses.json"))]
+    stream = pkg_resources.resource_stream(__name__, "data/poses.json")
+    return [Pose(**row) for row in json.load(stream)]
 
 
-def read_flows() -> List[List[str]]:
-    result = json.load(open_data("data/flows/flows-tobin.json"))
+def parse_flows(stream: IO[bytes]) -> List[List[str]]:
+    result = json.load(stream)
 
     if not isinstance(result, list):
         raise ValueError("Flow file does not contain a list of flows")
@@ -32,3 +29,13 @@ def read_flows() -> List[List[str]]:
                 raise ValueError("Pose is not a string")
 
     return result
+
+
+def read_flows() -> List[List[str]]:
+    result = []
+
+    for name in pkg_resources.resource_listdir(__name__, "data/flows"):
+        stream = pkg_resources.resource_stream(__name__, "data/flows/" + name)
+        result.extend(parse_flows(stream))
+
+    return result
